<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Escolha uma aplicação</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Aplicações instaladas</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Comando personalizado</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Linha de comandos a executar:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Nome da aplicação:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Esses códigos especiais podem ser usados na linha de comando:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Representa um único nome de ficheiro&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Representa vários nomes de ficheiros&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Representa um único URI do ficheiro&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Representa vários URI&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Manter janela de terminal aberta depois de executar o comando</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Executar no emulador de terminal</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Definir a aplicação selecionada como padrão para este tipo de ficheiro</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Editar marcadores</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Adicionar item</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Remover item</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Utilize &apos;arrastar e largar&apos; para organizar os itens</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Executar ficheiro</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>E&amp;xecutar</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Executar no &amp;terminal</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="99"/>
        <source>Remember for next files of this kind</source>
        <translation>Lembrar para os próximos ficheiros deste tipo</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Caminho:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Nome do ficheiro:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Tipo de ficheiro:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Processamento:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Preparação...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Tempo restante:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>Ficheiros processados:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Propriedades do ficheiro</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Tipo de ficheiro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Tipo MIME:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Tamanho do ficheiro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Tamanho no disco:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Última modificação:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Destino da ligação:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Abrir com:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Último acesso:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Criado:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Contém:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Emblema:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Escolha o emblema</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Remover emblema</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Device Usage:</source>
        <translation>Utilização do dispositivo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Permissões</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Titularidade</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="463"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="476"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Proprietário:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Controlo de acesso</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Outro:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Marcar ficheiro como executável</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Escrita</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Execução</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="742"/>
        <source>Sticky</source>
        <translation>Fixo</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>SetUID</source>
        <translation>Definir UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetGID</source>
        <translation>Definir GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Modo avançado</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Selecione uma aplicação para abrir os ficheiros &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Ficheiro vazio</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>O diretório especificado &apos;%1&apos; é inválido</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Sem sub-pastas&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Abrir em novo sep&amp;arador</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Abrir em nova ja&amp;nela</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Abrir no termina&amp;l</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Copiar aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Mover aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Criar ligação simbólica aqui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Não pode largar aqui</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Novo marcador</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Parece que &apos;%1&apos; é uma entrada &apos;desktop&apos;.
O que deseja fazer?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Parece que o ficheiro de texto %1 é um script executável.
O que deseja fazer?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>O ficheiro %1 é um executável. Deseja executar?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="106"/>
        <source>Go Back</source>
        <translation>Recuar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="107"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Seta esquerda</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="113"/>
        <source>Go Forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="114"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Seta direita</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="121"/>
        <source>Reload</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="139"/>
        <source>Create Folder</source>
        <translation>Criar pasta</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="155"/>
        <source>Icon View</source>
        <translation>Vista de ícones</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="159"/>
        <source>Thumbnail View</source>
        <translation>Vista de miniaturas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="163"/>
        <source>Compact View</source>
        <translation>Vista compacta</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="167"/>
        <source>Detailed List View</source>
        <translation>Vista detalhada</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="175"/>
        <source>Icon Sizes</source>
        <translation>Tamanho dos ícones</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="177"/>
        <source>Size of big icons:</source>
        <translation>Tamanho dos ícones grandes:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Size of small icons:</source>
        <translation>Tamanho dos ícones pequenos:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="191"/>
        <source>Size of thumbnails:</source>
        <translation>Tamanho das miniaturas:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="207"/>
        <source>Show Hidden</source>
        <translation>Mostrar ocultos</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="219"/>
        <source>Show Thumbnails</source>
        <translation>Mostrar miniaturas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="224"/>
        <source>Show File Tooltips</source>
        <translation>Mostrar dicas para ficheiros</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="231"/>
        <source>Smooth Scrolling</source>
        <translation>Deslocamento suave</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="246"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="596"/>
        <location filename="../filedialog.cpp" line="991"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="596"/>
        <source>Please select a file</source>
        <translation>Selecione um ficheiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="638"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 já existe.
Deseja substituir?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="961"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Caminho &quot;%1&quot; não existe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="975"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; não é um diretório</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="981"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; não é um ficheiro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1129"/>
        <location filename="../filedialog.cpp" line="1237"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1132"/>
        <location filename="../filedialog.cpp" line="1245"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1139"/>
        <source>All Files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="138"/>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Save File</source>
        <translation>Guardar ficheiro</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="356"/>
        <source>Many files</source>
        <translation>Demasiados ficheiros</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="357"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Deseja abrir %1 ficheiro?</numerusform>
            <numerusform>Deseja abrir %1 ficheiros?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="154"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="158"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="162"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="166"/>
        <location filename="../filemenu.cpp" line="484"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mover para o lixo</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="240"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Eject</source>
        <translation>Ejetar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="313"/>
        <source>Trust selected executables</source>
        <translation>Confiar nos executáveis selecionados</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="314"/>
        <source>Trust this executable</source>
        <translation>Confiar neste executável</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="148"/>
        <location filename="../filemenu.cpp" line="484"/>
        <source>&amp;Delete</source>
        <translation>&amp;Apagar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="170"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Abrir com...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Other Applications</source>
        <translation>Outras aplicações</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="125"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;novo(a)</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="144"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="275"/>
        <source>Extract to...</source>
        <translation>Extrair para...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Extract Here</source>
        <translation>Extrair aqui</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="290"/>
        <source>Compress</source>
        <translation>Comprimir</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="299"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Alguns ficheiros não podem ser movidos para o lixo porque o sistema de ficheiros subjacente não permite esta operação.
Deseja, em alternativa, apagar os ficheiros?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Confirmação</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Deseja eliminar o ficheiro selecionado?</numerusform>
            <numerusform>Deseja eliminar os ficheiros selecionados?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Deseja mover o ficheiro selecionado para o caixote do lixo?</numerusform>
            <numerusform>Deseja mover os ficheiros selecionados para o caixote do lixo?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Mover ficheiros</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>A mover os ficheiros para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Copiar ficheiros</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>A copiar os ficheiros para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Reciclar ficheiros</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>A mover os ficheiros para o lixo:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Apagar ficheiros</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>A apagar estes ficheiros:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Criar ligações simbólicas</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>A criar ligações simbólicas para estes ficheiros:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Alterar atributos</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>A alterar os atributos destes ficheiros:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Restaurar ficheiros apagados</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>A restaurar estes ficheiros do lixo:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Ver conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Ver e modificar conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Leitura e escrita</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Proibido</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>Ficheiros de outro tipo</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>Vários ficheiros</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="405"/>
        <source>%p% used</source>
        <translation>%p% utilizado</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="406"/>
        <source>%1 Free of %2</source>
        <translation>%1 de %2 livre</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="452"/>
        <source>no file</source>
        <translation>nenhum ficheiro</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="454"/>
        <source>one file</source>
        <translation>um ficheiro</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="456"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln ficheiro</numerusform>
            <numerusform>%Ln ficheiros</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="490"/>
        <location filename="../filepropsdialog.cpp" line="535"/>
        <source>Select an icon</source>
        <translation>Selecione um ícone</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="492"/>
        <location filename="../filepropsdialog.cpp" line="537"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Imagens (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="643"/>
        <source>Apply changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="644"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Pretende aplicar as alterações recursivamente a todos os ficheiros e sub-pastas?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>Deve adicionar pelo menos um diretório para pesquisar.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Selecionar uma pasta</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="479"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Não pode copiar um diretório para si próprio!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="530"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Não é possível criar uma ligação em sistemas não nativos</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Esvaziar lixo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;novo(a)</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="88"/>
        <source>Select &amp;All</source>
        <translation>Selecion&amp;ar tudo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="92"/>
        <source>Invert Selection</source>
        <translation>Inverter seleção</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="99"/>
        <source>Sorting</source>
        <translation>Ordenação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="104"/>
        <source>Show Hidden</source>
        <translation>Mostrar ocultos</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="139"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Pr&amp;opriedades da pasta</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="182"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="204"/>
        <source>By File Name</source>
        <translation>Por nome de ficheiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By Modification Time</source>
        <translation>Por data de modificação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Creation Time</source>
        <translation>Por data de criação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="209"/>
        <source>By Deletion Time</source>
        <translation>Por data de eliminação</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="212"/>
        <source>By File Size</source>
        <translation>Por tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Type</source>
        <translation>Por tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Owner</source>
        <translation>Pelo dono do ficheiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Group</source>
        <translation>Por grupo de ficheiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="221"/>
        <source>Ascending</source>
        <translation>Ascendente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="226"/>
        <source>Descending</source>
        <translation>Descendente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="243"/>
        <source>Folder First</source>
        <translation>Pastas primeiro</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="251"/>
        <source>Hidden Last</source>
        <translation>Oculto por último</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="259"/>
        <source>Case Sensitive</source>
        <translation>Diferenciar maiúsculas/minúsculas</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Tipo de ficheiro:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Tamanho do ficheiro:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Última modificação:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Último acesso:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Criado:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Proprietário:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Criado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Eliminado</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Proprietário</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="409"/>
        <source>Auto-resize columns</source>
        <translation>Ajustar colunas automaticamente</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="426"/>
        <source>Visible Columns</source>
        <translation>Colunas visíveis</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Conectar</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="122"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Editar caminho</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="125"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Copiar caminho</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Locais</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Dispositivos</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="570"/>
        <source>Empty Trash</source>
        <translation>Esvaziar lixo</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="555"/>
        <source>Open in New Tab</source>
        <translation>Abrir em novo separador</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="558"/>
        <source>Open in New Window</source>
        <translation>Abrir em nova janela</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="590"/>
        <location filename="../placesview.cpp" line="652"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="607"/>
        <source>Move Bookmark Up</source>
        <translation>Mover marcador para cima</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="614"/>
        <source>Move Bookmark Down</source>
        <translation>Mover marcador para baixo</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="619"/>
        <source>Rename Bookmark</source>
        <translation>Renomear marcador</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="623"/>
        <source>Remove Bookmark</source>
        <translation>Remover marcador</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <location filename="../placesview.cpp" line="666"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="637"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <source>Eject</source>
        <translation>Ejetar</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="678"/>
        <source>Show All Entries</source>
        <translation>Mostrar todas as entradas</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tipo: %1
Tamanho: %2
Modificado: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tipo: %1
Modificado: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="97"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Substituir</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="99"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="109"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;O ficheiro não se pode substituir a si próprio.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Deve escolher outro nome.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Listas</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Árvore de diretórios</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Não é possível restaurar &apos;%s&apos;: caminho desconhecido</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Conectar &amp;anonimamente</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Conectar com o u&amp;tilizador:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>Nome de &amp;utilizador:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Palavra-passe:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domínio:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Esquecer palavra-passe &amp;imediatamente</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>A duração da sessão é determinada pelo gestor de palavras-passe</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>Memorizar palavra-passe para es&amp;ta sessão</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Memori&amp;zar eternamente</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="669"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Renomear ficheiro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Introduza o novo nome:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Criar pasta</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Introduza o nome para o ficheiro:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Novo ficheiro</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Introduza o nome para a pasta:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Nova pasta</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Introduza um nome para %1:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Criar ficheiro</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="687"/>
        <source>Custom Icon Error</source>
        <translation>Erro no ícone personalizado</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>O caminho não está montado.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Ficheiro .desktop inválido: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Não está definida uma aplicação padrão para iniciar &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Não é possível definir o diretório de trabalho para &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identificador: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Confirmação de substituição</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Já existe um ficheiro com o mesmo nome nesta localização.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Deseja substituir o ficheiro existente&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>por este?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>Nome do &amp;ficheiro:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Aplicar opção para todos os ficheiros existentes</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Pesquisar ficheiros</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nome/localização</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Padrões para nome de ficheiro:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Locais a pesquisar:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Pesquisar por ficheiros ocultos</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Pesquisar apenas por ficheiros deste tipo:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Ficheiros de texto</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Ficheiros de áudio</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Pastas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Ficheiro contém:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Tamanho do ficheiro:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <source>Larger than:</source>
        <translation>Maior do que:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="316"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="321"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="326"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="331"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Smaller than:</source>
        <translation>Menor do que:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Diferenciar maiúsculas/minúsculas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Pesquisar em sub-diretórios</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Diferenciar &amp;maiúsculas/minúsculas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Data da última modificação:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Anterior a:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="392"/>
        <source>Later than:</source>
        <translation>Posterior a:</translation>
    </message>
</context>
</TS>
